==> istio-model-v1beta1-6.7.2-sources.jar: io/fabric8/istio/api/networking/v1beta1/HeadersHeaderOperationsBuilder.java <==
package io.fabric8.istio.api.networking.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class HeadersHeaderOperationsBuilder extends HeadersHeaderOperationsFluentImpl<HeadersHeaderOperationsBuilder> implements VisitableBuilder<HeadersHeaderOperations,HeadersHeaderOperationsBuilder>{
  public HeadersHeaderOperationsBuilder() {
    this(false);
  }
  public HeadersHeaderOperationsBuilder(Boolean validationEnabled) {
    this(new HeadersHeaderOperations(), validationEnabled);
  }
  public HeadersHeaderOperationsBuilder(HeadersHeaderOperationsFluent<?> fluent) {
    this(fluent, false);
  }
  public HeadersHeaderOperationsBuilder(HeadersHeaderOperationsFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new HeadersHeaderOperations(), validationEnabled);
  }
  public HeadersHeaderOperationsBuilder(HeadersHeaderOperationsFluent<?> fluent,HeadersHeaderOperations instance) {
    this(fluent, instance, false);
  }
  public HeadersHeaderOperationsBuilder(HeadersHeaderOperationsFluent<?> fluent,HeadersHeaderOperations instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withAdd(instance.getAdd());
      fluent.withRemove(instance.getRemove());
      fluent.withSet(instance.getSet());
    }
    this.validationEnabled = validationEnabled; 
  }
  public HeadersHeaderOperationsBuilder(HeadersHeaderOperations instance) {
    this(instance,false);
  }
  public HeadersHeaderOperationsBuilder(HeadersHeaderOperations instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withAdd(instance.getAdd());
      this.withRemove(instance.getRemove());
      this.withSet(instance.getSet());
    }
    this.validationEnabled = validationEnabled; 
  }
  HeadersHeaderOperationsFluent<?> fluent;
  Boolean validationEnabled;
  public HeadersHeaderOperations build() {
    HeadersHeaderOperations buildable = new HeadersHeaderOperations(fluent.getAdd(),fluent.getRemove(),fluent.getSet());
    return buildable;
  }
  
}

==> istio-model-v1beta1-6.8.1-sources.jar: io/fabric8/istio/api/networking/v1beta1/HeadersHeaderOperationsBuilder.java <==
package io.fabric8.istio.api.networking.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class HeadersHeaderOperationsBuilder extends HeadersHeaderOperationsFluent<HeadersHeaderOperationsBuilder> implements VisitableBuilder<HeadersHeaderOperations,HeadersHeaderOperationsBuilder>{
  public HeadersHeaderOperationsBuilder() {
    this(false);
  }
  public HeadersHeaderOperationsBuilder(Boolean validationEnabled) {
    this(new HeadersHeaderOperations(), validationEnabled);
  }
  public HeadersHeaderOperationsBuilder(HeadersHeaderOperationsFluent<?> fluent) {
    this(fluent, false);
  }
  public HeadersHeaderOperationsBuilder(HeadersHeaderOperationsFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new HeadersHeaderOperations(), validationEnabled);
  }
  public HeadersHeaderOperationsBuilder(HeadersHeaderOperationsFluent<?> fluent,HeadersHeaderOperations instance) {
    this(fluent, instance, false);
  }
  public HeadersHeaderOperationsBuilder(HeadersHeaderOperationsFluent<?> fluent,HeadersHeaderOperations instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new HeadersHeaderOperations());

    if (instance != null) {
      fluent.withAdd(instance.getAdd());
      fluent.withRemove(instance.getRemove());
      fluent.withSet(instance.getSet());
      fluent.withAdd(instance.getAdd());
      fluent.withRemove(instance.getRemove());
      fluent.withSet(instance.getSet());
    }
    this.validationEnabled = validationEnabled; 
  }
  public HeadersHeaderOperationsBuilder(HeadersHeaderOperations instance) {
    this(instance,false);
  }
  public HeadersHeaderOperationsBuilder(HeadersHeaderOperations instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new HeadersHeaderOperations());

    if (instance != null) {
      this.withAdd(instance.getAdd());
      this.withRemove(instance.getRemove());
      this.withSet(instance.getSet());
      this.withAdd(instance.getAdd());
      this.withRemove(instance.getRemove());
      this.withSet(instance.getSet());
    }
    this.validationEnabled = validationEnabled; 
  }
  HeadersHeaderOperationsFluent<?> fluent;
  Boolean validationEnabled;
  public HeadersHeaderOperations build() {
    HeadersHeaderOperations buildable = new HeadersHeaderOperations(fluent.getAdd(),fluent.getRemove(),fluent.getSet());
    return buildable;
  }
  
}
